@@ -23,6 +23,11 @@ def test_function():
 def test_pandas(filepath):
     return pd.read_csv(filepath,sep=';')
 
+
+def current_version():
+    print('0.0.7')
+
+
 ###################################################################################################################
 ########################################## Intercom ###############################################################
 ###################################################################################################################
